from setuptools import setup, find_packages

VERSION = '1.0'
DESCRIPTION = 'Python Tools - (Log)'

setup(name='u4nf',
      version=VERSION,
      description=DESCRIPTION,
      author='4nf',
      packages=find_packages()
     )
